@@ -9,7 +9,7 @@ use parent 'Class::Accessor';
 use Travel::Status::DE::DBRIS::Location;
 use Travel::Status::DE::DBRIS::Operators;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 # ->number is deprecated
 # TODO: Rename ->train, ->train_no to ->trip, ->trip_no
@@ -51,17 +51,15 @@ sub new {
 			my @admin_id_argmax
 			  = reverse sort { $admin_id_ml{$a} <=> $admin_id_ml{$b} }
 			  keys %admin_id_ml;
-			if ( defined( my $admin_id = $admin_id_ml{ $admin_id_argmax[0] } ) )
+			$ref->{admin_id} = $admin_id_argmax[0];
+			if (
+				my $op
+				= Travel::Status::DE::DBRIS::Operators::get_operator_name(
+					$ref->{admin_id}
+				)
+			  )
 			{
-				$ref->{admin_id} = $admin_id;
-				if (
-					my $op
-					= Travel::Status::DE::DBRIS::Operators::get_operator_name(
-						$admin_id)
-				  )
-				{
-					$ref->{operator} = $admin_id;
-				}
+				$ref->{operator} = $op;
 			}
 
 			# return most frequent admin ID first
@@ -78,9 +76,8 @@ sub new {
 			my @trip_no_argmax
 			  = reverse sort { $trip_no_ml{$a} <=> $trip_no_ml{$b} }
 			  keys %trip_no_ml;
-			if ( defined( my $trip_no = $trip_no_ml{ $trip_no_argmax[0] } ) ) {
-				$ref->{train_no_no} = $trip_no;
-			}
+			$ref->{train_no}     = $trip_no_argmax[0];
+			$ref->{trip_numbers} = \@trip_no_argmax;
 		}
 	}
 
@@ -224,6 +221,27 @@ sub operators {
 	return @{ $self->{operators} // [] };
 }
 
+sub trip_numbers {
+	my ($self) = @_;
+
+	return @{ $self->{trip_numbers} // [] };
+}
+
+sub trip_no_at {
+	my ( $self, $loc, $ts ) = @_;
+	for my $stop ( $self->route ) {
+		if ( $stop->name eq $loc or $stop->eva eq $loc ) {
+			if (   not defined $ts
+				or not( $stop->sched_dep // $stop->sched_arr )
+				or ( $stop->sched_dep // $stop->sched_arr )->epoch == $ts )
+			{
+				return $stop->trip_no;
+			}
+		}
+	}
+	return;
+}
+
 sub TO_JSON {
 	my ($self) = @_;
 
@@ -262,7 +280,7 @@ journey received by Travel::Status::DE::DBRIS
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -315,6 +333,13 @@ Textual description of the departure, typically consisting of type identifier
 
 Trip number, if available. undef otherwise.
 
+=item $journey->trip_no_at($stop, $epoch)
+
+Return trip number at I<$stop> (name or EVA ID), if available.  Optionally,
+I<$epoch> can be used to only match stops where scheduled departure or arrival
+is equal to I<$epoch>. This is useful in case a trip passes the same stop
+multiple times.
+
 =item $journey->line_no
 
 Line identifier, if available. undef otherwise. Note that the line identifier
