@@ -6,11 +6,11 @@ use 5.020;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 Travel::Status::DE::DBRIS::Location->mk_ro_accessors(
 	qw(eva id lat lon name admin_id products type is_cancelled is_additional is_separation display_priority
-	  dep arr sched_dep sched_arr rt_dep rt_arr arr_delay dep_delay delay
+	  trip_no dep arr sched_dep sched_arr rt_dep rt_arr arr_delay dep_delay delay
 	  platform sched_platform rt_platform
 	  occupancy_first occupancy_second occupancy
 	)
@@ -76,6 +76,9 @@ sub new {
 	if ( $json->{adminID} ) {
 		$ref->{admin_id} = $json->{adminID};
 	}
+	if ( $json->{nummer} ) {
+		$ref->{trip_no} = $json->{nummer};
+	}
 
 	for my $occupancy ( @{ $json->{auslastungsmeldungen} // [] } ) {
 		if ( $occupancy->{klasse} eq 'KLASSE_1' ) {
